@@ -1161,6 +1161,10 @@ impl<'a, I: Tokens> StmtLikeParser<'a, Stmt> for Parser<I> {
         }
 
         if self.input.syntax().import_meta() && is!(self, "import") && peeked_is!(self, '.') {
+            if !self.ctx().module {
+                syntax_error!(self, SyntaxError::ImportMetaInScript);
+            }
+
             let expr = self.parse_expr()?;
 
             eat!(self, ';');
@@ -1790,4 +1794,18 @@ export default function waitUntil(callback, options = {}) {
             _ => assert!(false),
         }
     }
+
+    #[test]
+    #[should_panic(expected = "'import.meta' cannot be used outside of module code.")]
+    fn import_meta_in_script() {
+        let src = "import.meta.url;";
+        test_parser(
+            src,
+            Syntax::Es(EsConfig {
+                import_meta: true,
+                ..Default::default()
+            }),
+            |p| p.parse_script(),
+        );
+    }
 }
